unit HFReader_Head;

interface

Const
    COM1 = 1;
    COM2 = 2;
    COM3 = 3;
    COM4 = 4;
    COM5 = 5;
    COM6 = 6;
    COM7 = 7;
    COM8 = 8;
    COM9 = 9;
    COM10 = 10;

    OK			    	= $00;
    LengthError         = $01;
    OperationNotSupport = $02;
    DataRangError       = $03;
    CmdNotOperation     = $04;
    RfClosed            = $05;
    EEPROM              = $06;
    TimeOut             = $0a;
    MoreUID             = $0b;
    ISOError            = $0c;
    NoElectronicTag     = $0e;
    OperationError      = $0f;


    CmdNotSupport                 = $01;
    CmdNotIdentify                = $02;
    OperationNotSupport_          = $03;
    UnknownError                  = $0f;
    BlockError                    = $10;
    BlockLockedAndCntLock         = $11;
    BlockLockedAndCntWrite        = $12;
    BlockCntOperate               = $13;
    BlockCntLock                  = $14;

    CommunicationErr = $30;
    RetCRCErr        = $31;
    RetDataErr       = $32;    //ݳд
    CommunicationBusy= $33;
    ExecuteCmdBusy   = $34;
    ComPortOpened    = $35;
    ComPortClose     = $36;
    InvalidHandle    = $37;
    InvalidPort      = $38;

    SRI512_4K_Initiate_Failed	 = $11;
    SRI512_4K_Select_Failed	   = $12;
    SRI512_4K_Completion_Failed	= $13;
    SRI512_4K_ReadBlock_Failed 	= $14;
    SRI512_4K_WriteBlock_Failed	= $15;
    SRI512_4K_GetUID_Failed	 = $18;
    SRI512_4K_PCall16_Failed = $19;
    SRI512_4K_SlotMarker_Failed =	$1A;


    Function HFReader_GetBlockSize_BlockNum(Firmcode,OtherCode : Byte;
                                          Var FirmName : String;
                                          Var BlockSize,BlockNum : Byte;
                                          Var BlockStyle : String) : Boolean;
    Function HFReader_GetErrorCodeDesc(errorCode : Byte) : String;
    Function HFReader_GetReturnCodeDesc(retCode : Byte) : String;
    function GetSRIErrCodeDesc(errcode:longint):string;
    Function GeteCodeDesc(retCode : string) : String;

    implementation

    Function GeteCodeDesc(retCode : string) : String;
    begin
        result := '';
        if(retCode='C')then
        begin
           result := 'Command Error';
        end
        else if(retCode='R')then
        begin
          Result:='Device refused to do the order';
        end
        else if(retCode='D')then
        begin
          Result:='can not connect with device';
        end
        else if(retCode='F') then
        begin
          Result:='Command execution failed';
        end;
    end;

Function HFReader_GetBlockSize_BlockNum(Firmcode,OtherCode : Byte;
                                      Var FirmName : String;
                                      Var BlockSize,BlockNum : Byte;
                                      Var BlockStyle : String) : Boolean;
Begin
   result := true;
   case FirmCode of
       $05 :
           Begin
               FirmName := 'Infineon';   //(ISO Address mode)
               BlockSize:= 4;
               BlockNum := 58;
               if OtherCode=$E0 then BlockNum := 250
               else if OtherCode=$60 then BlockNum := 58;

               BlockStyle := 'B';   //B
           end;
       $02 :
           Begin
               FirmName := 'STMicroelectronics';   //(LRI512)
               BlockSize:= 4;
               BlockNum := 16;

               BlockStyle := 'B';   //B
           end;
       $08 :
           Begin
               FirmName := 'Fujitsu';    //(MB89R116)
               BlockSize:= 8;
               BlockNum := 250;

               BlockStyle := 'AB';   //AB
           end;
       $04 :
           Begin
               FirmName := 'Philips Semiconductors';   //(I-Code SLI)
               BlockSize:= 4;
               BlockNum := 28;

               BlockStyle := 'B';   //B
           end;
       $07 :
           Begin
               FirmName := 'Texas Instruments';   //(Tag-itHF-I)
               BlockSize:= 4;
               BlockNum := 64;

               BlockStyle := 'A';   //A
           end;
     //-------------------------------------------------------------------------
      $16 :                           //FirmCode $16
                                       //2006-8-2 ޸ļ'EM Microelectronic '
            begin
              FirmName := 'EM Microelectronic '  ;  //
              BlockSize:= 4;                      //    ??
              BlockNum := 14;                     // ??
              BlockStyle := 'A';              //AB//??
            end;
        //------------------------------------------- --------------------------
       else
           result := False;
   end;
end;

Function HFReader_GetErrorCodeDesc(errorCode : Byte) : String;
begin
    result := '';
    case errorCode of
        CmdNotSupport         : result := 'Commands  not supported';
        CmdNotIdentify        : result := 'Unknown Command';
        OperationNotSupport_  : result := 'Operation not support';
        UnknownError          : result := 'Unknown error';
        BlockError            : result := 'Appointed  block can not be used or does not exist';
        BlockLockedAndCntLock : result := 'Appointed  block is locked';
        BlockLockedAndCntWrite: result := 'Appointed  block is locked';
        BlockCntOperate       : result := 'Appointed  block can not be operated normally';
        BlockCntLock          : result := 'Appointed  block can not be locked normally';
        CmdNotOperation       : result := 'Command can not execute at current';
        NoElectronicTag       : Result := 'No tag';
        $33                   : RESULT := 'Utralight tag anticollision failed' ;
        $32                   : RESULT := 'MF1 and Utralight tag collision';
        $31                   : RESULT := 'Unallow more than one tag in RF field';
        $30                   : RESULT := 'Anticollision failed';
        $2E                   : RESULT := 'Utralight tag write failed' ;
        $2D                   : RESULT := 'Value operation failed';
        $2C                   : RESULT := 'CheckWrite data not match';
        $2B                   : RESULT := 'Check write failed'  ;
        $2A                   : RESULT := 'Storage key failed' ;
        $29                   : RESULT := 'Read/Write E2PROM failed' ;
        $28                   : RESULT := 'Transfer failed';
        $27                   : RESULT := 'Increment/Decrement failed';
        $26                   : RESULT := 'Read e-Wallet failed';
        $25                   : RESULT := 'e-Wallet initialization failed';
        $24                   : RESULT := 'Write failed';
        $23                   : RESULT := 'Read failed';
        $22                   : RESULT := 'Authentication failed';
        $21                   : RESULT := 'Select failed';
        $20                   : RESULT := 'No ISO14443A tag';
        $34                   : RESULT := 'No ISO14443B tag';
        $35                   : RESULT := 'Select failed';
        $36                   : RESULT := 'Halt failed';
        $37                   : RESULT := 'Transparent failed';
        $38                   : RESULT := 'Anticollision failed';
    end;
end;

Function HFReader_GetReturnCodeDesc(retCode : Byte) : String;
begin
    result := '';
    case retCode of
        LengthError         : result := 'Command operand length error';
        OperationNotSupport : result := 'Command not supported';
        RfClosed            : result := 'RF field is inactive';
        EEPROM              : result := 'E2PROM operation error';
        TimeOut             : result := 'InventoryScanTime overflow';
        MoreUID             : result := 'Not all tag'''+'s UID are collected';
        ISOError            : result := 'ISO error';
        NoElectronicTag     : result := 'No tags';
        OperationError      : result := 'Operation error';
        CommunicationErr    : result := 'Communication Error';
        RetCRCErr           : result := 'CRC checksummat Error';
        RetDataErr          : result := 'Return data error';   
        CommunicationBusy   : result := 'Communication error';
        CmdNotOperation     : result := 'CMD can''' +'t execute at current';
        DataRangError       : result := 'Operation data range error';
        InvalidHandle       : result := 'Invalid PortHandle';
        $1F                 : result := 'Work pattern error';
    end;
end;

function GetSRIErrCodeDesc(errcode:longint):string;
begin
  result := '';
  case  errcode of
    SRI512_4K_Initiate_Failed:    result := 'Initiate failed';
    SRI512_4K_Select_Failed	 :    result := 'Select failed';
    SRI512_4K_Completion_Failed:  result := 'Completion failed';
    SRI512_4K_ReadBlock_Failed :  result := 'ReadBlock failed';
    SRI512_4K_WriteBlock_Failed:  result := 'WriteBlock failed';
    SRI512_4K_GetUID_Failed	 :    result := 'GetUID failed';
    SRI512_4K_PCall16_Failed :    result := 'PCall16 failed';
    SRI512_4K_SlotMarker_Failed:  result := 'SlotMarker failed';
  end
end;

end.
